@@ -1285,3 +1285,34 @@ Image::DiskType Datastore::context_disk_type() const
 
     return Image::FILE;
 }
+
+/* ------------------------------------------------------------------------ */
+/* ------------------------------------------------------------------------ */
+
+string Datastore::bridge(int vm_id) const
+{
+    std::string bridges_str;
+
+    if (!get_template_attribute("BRIDGE_LIST", bridges_str))
+    {
+        return "";
+    }
+
+    bridges_str = one_util::gsub(bridges_str, "'", "");
+    bridges_str = one_util::gsub(bridges_str, "\"", "");
+    bridges_str = one_util::trim(bridges_str);
+
+    if (bridges_str.empty())
+    {
+        return "";
+    }
+
+    auto bridges = one_util::split(bridges_str, ',', true);
+
+    if (bridges.empty())
+    {
+        return "";
+    }
+
+    return bridges[vm_id % bridges.size()];
+}
