@@ -16,7 +16,9 @@
 
 #include "DispatchManager.h"
 #include "NebulaLog.h"
+#include <fstream>
 
+#include "DatastorePool.h"
 #include "VirtualMachineManager.h"
 #include "TransferManager.h"
 #include "ImageManager.h"
@@ -2265,7 +2267,10 @@ int DispatchManager::disk_resize(int vid, int did, long long new_size,
         default: break;
     }
 
-    close_cp_history(vmpool, vm.get(), VMActions::DISK_RESIZE_ACTION, ra);
+    if (state != VirtualMachine::UNDEPLOYED)
+    {
+        close_cp_history(vmpool, vm.get(), VMActions::DISK_RESIZE_ACTION, ra);
+    }
 
     vmpool->update(vm.get());
 
@@ -2642,7 +2647,17 @@ int DispatchManager::backup(int vid, int backup_ds_id, bool reset,
             return -1;
     }
 
-    vm->backups().last_datastore_id(backup_ds_id);
+    if (auto ds = Nebula::instance().get_dspool()->get_ro(backup_ds_id))
+    {
+        auto bridge = ds->bridge(vid);
+
+        if (!bridge.empty())
+        {
+            vm->backups().last_bridge(bridge);
+        }
+    }
+
+    vm->backups().last_datastore_id( backup_ds_id );
 
     if (reset)
     {
@@ -2809,16 +2824,20 @@ int DispatchManager::resize(int vid, float cpu, int vcpu, long memory, bool enfo
     }
 
     int rc;
+    bool update_history = true;
 
     switch (vm->get_state())
     {
-        case VirtualMachine::POWEROFF: //Only check host capacity in POWEROFF
         case VirtualMachine::INIT:
         case VirtualMachine::PENDING:
         case VirtualMachine::HOLD:
         case VirtualMachine::UNDEPLOYED:
         case VirtualMachine::CLONING:
         case VirtualMachine::CLONING_FAILURE:
+            update_history = false;
+            [[fallthrough]];
+
+        case VirtualMachine::POWEROFF: //Only check host capacity in POWEROFF
             rc = test_set_capacity(vm.get(), cpu, memory, vcpu, enforce, error_str);
             break;
 
@@ -2886,7 +2905,7 @@ int DispatchManager::resize(int vid, float cpu, int vcpu, long memory, bool enfo
 
     if (rc == 0)
     {
-        if (vm->hasHistory())
+        if (vm->hasHistory() && update_history)
         {
             close_cp_history(vmpool, vm.get(), VMActions::RESIZE_ACTION, ra);
         }
@@ -2933,7 +2952,7 @@ int DispatchManager::attach_pci(int vid, VectorAttribute * pci,
 
     unique_ptr<Host> host;
 
-    if (vm->get_state() ==  VirtualMachine::POWEROFF)
+    if (vm->get_state() == VirtualMachine::POWEROFF)
     {
         HostShareCapacity sr;
 
@@ -2965,7 +2984,10 @@ int DispatchManager::attach_pci(int vid, VectorAttribute * pci,
         hpool->update(host.get());
     }
 
-    close_cp_history(vmpool, vm.get(), VMActions::PCI_ATTACH_ACTION, ra);
+    if (vm->get_state() != VirtualMachine::UNDEPLOYED)
+    {
+        close_cp_history(vmpool, vm.get(), VMActions::PCI_ATTACH_ACTION, ra);
+    }
 
     vm->log("DiM", Log::INFO, "PCI device successfully attached.");
 
@@ -3036,7 +3058,10 @@ int DispatchManager::detach_pci(int vid, int pci_id, const RequestAttributes& ra
 
     vm->detach_pci(vpci);
 
-    close_cp_history(vmpool, vm.get(), VMActions::PCI_DETACH_ACTION, ra);
+    if (vm->get_state() != VirtualMachine::UNDEPLOYED)
+    {
+        close_cp_history(vmpool, vm.get(), VMActions::PCI_DETACH_ACTION, ra);
+    }
 
     vm->log("DiM", Log::INFO, "PCI device successfully deatached.");
 
