@@ -17,5 +17,12 @@ import { COMMON_FIELDS } from './common'
 import { CEPH_FIELDS } from './ceph'
 import { RESTIC_FIELDS } from './restic'
 import { RSYNC_FIELDS } from './rsync'
+import { NETAPP_FIELDS } from './netapp'
 
-export { COMMON_FIELDS, CEPH_FIELDS, RESTIC_FIELDS, RSYNC_FIELDS }
+export {
+  COMMON_FIELDS,
+  CEPH_FIELDS,
+  RESTIC_FIELDS,
+  RSYNC_FIELDS,
+  NETAPP_FIELDS,
+}
