@@ -13,14 +13,9 @@
  * See the License for the specific language governing permissions and       *
  * limitations under the License.                                            *
  * ------------------------------------------------------------------------- */
-import {
-  J2xOptions,
-  parse as ParserToJson,
-  j2xParser as ParserToXml,
-  X2jOptions,
-} from 'fast-xml-parser'
+import { XMLBuilder, XMLParser } from 'fast-xml-parser'
+import { set, get, isEmpty, isNaN } from 'lodash'
 import { DateTime, Settings } from 'luxon'
-import { isEmpty, isNaN } from 'lodash'
 
 import { sentenceCase } from '@UtilsModule'
 
@@ -34,23 +29,38 @@ import {
 
 /**
  * @param {object} json - JSON
- * @param {J2xOptions} [options] - Options to parser
+ * @param {object} [options] - Options to parser
  * @param {boolean} [options.addRoot] - Add ROOT element as parent
+ * @param {Array} options.excluded - Array of excluded paths
  * @returns {string} Xml in string format
  */
-export const jsonToXml = (json, { addRoot = true, ...options } = {}) => {
-  const parser = new ParserToXml(options)
+export const jsonToXml = (
+  json,
+  { addRoot = true, excluded = [], ...options } = {}
+) => {
+  excluded.forEach((path) => {
+    const val = get(json, path)
+    if (val !== undefined) set(json, path, { __cdata: val })
+  })
 
-  return parser.parse(addRoot ? { ROOT: json } : json)
+  const builder = new XMLBuilder({
+    ...options,
+    cdataPropName: '__cdata',
+    format: false,
+  })
+
+  const result = builder.build(addRoot ? { ROOT: json } : json)
+
+  return result
 }
 
 /**
  * @param {string} xml - XML in string format
- * @param {X2jOptions} [options] - Options to parser
+ * @param {object} [options] - Options to parser
  * @returns {object} JSON
  */
 export const xmlToJson = (xml, options = {}) => {
-  const { ROOT, ...jsonWithoutROOT } = ParserToJson(xml, {
+  const parser = new XMLParser({
     attributeNamePrefix: '',
     attrNodeName: '',
     ignoreAttributes: false,
@@ -62,6 +72,8 @@ export const xmlToJson = (xml, options = {}) => {
     ...options,
   })
 
+  const { ROOT, ...jsonWithoutROOT } = parser.parse(xml)
+
   return ROOT ?? jsonWithoutROOT
 }
 
@@ -322,6 +334,7 @@ export const getActionsAvailable = (actions = {}, hypervisor = '') =>
  * @param {string} id - Resource id
  * @param {object} oneConfig - OpenNEbula configuration
  * @param {boolean} adminGroup - If the user is admin
+ * @param {string} [resource] - Resource type, used to get the tab component
  * @returns {{
  * id: string,
  * name: string,
@@ -333,7 +346,8 @@ export const getAvailableInfoTabs = (
   getTabComponent,
   id,
   oneConfig,
-  adminGroup
+  adminGroup,
+  resource = ''
 ) =>
   Object.entries(infoTabs)
     ?.filter(([_, { enabled } = {}]) => !!enabled)
@@ -350,6 +364,7 @@ export const getAvailableInfoTabs = (
               id={id}
               oneConfig={oneConfig}
               adminGroup={adminGroup}
+              resource={resource}
             />
           ),
         }
