@@ -822,40 +822,6 @@ Request::ErrorCode VirtualNetworkTemplateAllocate::pool_allocate(
 /* -------------------------------------------------------------------------- */
 /* -------------------------------------------------------------------------- */
 
-bool VirtualNetworkTemplateAllocate::allocate_authorization(
-        xmlrpc_c::paramList const&  paramList,
-        Template *          tmpl,
-        RequestAttributes&  att,
-        PoolObjectAuth *    cluster_perms)
-{
-    AuthRequest ar(att.uid, att.group_ids);
-    string      aname;
-
-    if (!RequestManagerAllocate::allocate_authorization(paramList, tmpl, att, cluster_perms))
-    {
-        return false;
-    }
-
-    VirtualNetworkTemplate * ttmpl = static_cast<VirtualNetworkTemplate *>(tmpl);
-
-    // ------------ Check template for restricted attributes -------------------
-    if (!att.is_admin())
-    {
-        if (ttmpl->check_restricted(aname))
-        {
-            att.resp_msg = "VM Template includes a restricted attribute "+aname;
-
-            failure_response(AUTHORIZATION, att);
-            return false;
-        }
-    }
-
-    return true;
-}
-
-/* -------------------------------------------------------------------------- */
-/* -------------------------------------------------------------------------- */
-
 Request::ErrorCode HostAllocate::pool_allocate(
         xmlrpc_c::paramList const&  paramList,
         unique_ptr<Template>        tmpl,
