@@ -149,6 +149,7 @@ void OpenNebulaTemplate::set_multiple_conf_default()
     set_conf_auth("ssh", "YES", "NO", "NO", "-1");
     set_conf_auth("x509", "NO", "NO", "NO", "-1");
     set_conf_auth("ldap", "YES", "YES", "YES", "86400");
+    set_conf_auth("saml", "YES", "YES", "YES", "86400");
     set_conf_auth("server_cipher", "NO", "NO", "NO", "-1");
     set_conf_auth("server_x509", "NO", "NO", "NO", "-1");
 
@@ -384,6 +385,7 @@ void OpenNebulaTemplate::set_conf_default()
     set_conf_single("SHOWBACK_ONLY_RUNNING", "NO");
     set_conf_single("CONTEXT_RESTRICTED_DIRS", "/etc");
     set_conf_single("CONTEXT_SAFE_DIRS", "");
+    set_conf_single("CONTEXT_ALLOW_ETH_UPDATES", "NO");
 
     //DB CONFIGURATION
     vvalue.insert(make_pair("BACKEND", "sqlite"));
