@@ -679,7 +679,7 @@ class OneVMHelper < OpenNebulaHelper::OneHelper
         max_value = 80
 
         str_h1 = '%-80s'
-        str    = "%-20s: %-#{max_value}s"
+        str    = '%-20s: %s'
 
         trunc = lambda do |tvalue, max = max_value|
             return '' unless tvalue
@@ -751,6 +751,7 @@ class OneVMHelper < OpenNebulaHelper::OneHelper
 
         unit_lambda  = ->(v) { OpenNebulaHelper.unit_to_str(v.to_i, {}) }
         unitM_lambda = ->(v) { OpenNebulaHelper.unit_to_str(v.to_i / 1024, {}) }
+        unitG_lambda = ->(v) { OpenNebulaHelper.unit_to_str(v.to_i / 1024, {}, 'G') }
 
         order_attrs = {
             'CPU'         => nil,
@@ -766,7 +767,12 @@ class OneVMHelper < OpenNebulaHelper::OneHelper
             'DISKWRBYTES' => unit_lambda,
             'DISKWRBYTES_BW' => unit_lambda,
             'DISKWRIOPS_BW'  => nil,
-            'DISKWRIOPS'  => nil
+            'DISKWRIOPS'  => nil,
+            'GPU_COUNT' => nil,
+            'GPU_UTILIZATION' => nil,
+            'GPU_MEMORY_UTILIZATION' => nil,
+            'GPU_MEMORY_FREE' => unitG_lambda,
+            'GPU_POWER_USAGE' => nil
         }
 
         vm_monitoring_sort = []
