@@ -109,7 +109,7 @@ class OneDB
         rescue Gem::LoadError
             STDERR.puts(
                 'Augeas gem is not installed, run `gem install ' \
-                'opennebula-augeas` to install it'
+                'ruby-augeas` to install it'
             )
             exit(-1)
         end
