@@ -22,6 +22,7 @@ require 'json'
 require 'yaml'
 require 'rexml/document'
 require 'sqlite3'
+require 'csv'
 
 require_relative 'process_list'
 require_relative 'domain'
@@ -214,18 +215,23 @@ class Domain < BaseDomain
         @vm[:state]  = state
         @vm[:reason] = reason
 
-        # VM system datastore path
+        # Get VM virsh dumpxml ONE metadata
         xml, _e, s = KVM.virsh(:dumpxml, @name)
 
-        @vm[:system_datastore] = begin
-            doc = REXML::Document.new(xml)
-            doc.elements['/domain/metadata/one:vm/one:system_datastore']&.text
-        rescue 'StandardError'
-            nil
+        begin
+            dkeys = [:system_datastore, :pci_devices]
+            doc   = REXML::Document.new(xml)
+
+            dkeys.each do |k|
+                @vm[k] = doc.elements["/domain/metadata/one:vm/one:#{k}"]&.text
+            end
+        rescue StandardError
+            dkeys.each {|key| @vm[key] = nil }
         end if s.success?
 
         ga_stats
         io_stats
+        gpu_stats
     end
 
     # Convert the output of dumpxml for this domain to an OpenNebula template
@@ -342,6 +348,21 @@ class Domain < BaseDomain
     # List of domain state reasons (for RUNNING) when to skip I/O monitoring
     REASONS_SKIP_IO = ['migrating', 'starting up', 'saving']
 
+    # --------------------------------------------------------------------------
+    # GPU monitoring system - detects GPUs from PCI devices and collects metrics
+    # --------------------------------------------------------------------------
+    GPU_VENDORS = {
+        'nvidia' => {
+            :vendor_id     => '10de',
+            :monitor_class => 'NvidiaGPUMonitor'
+        }
+        # Add new vendors:
+        # 'amd' => {
+        #     :vendor_id     => '1002',
+        #     :monitor_class => 'AMDGPUMonitor'
+        # }
+    }.freeze
+
     # Get the I/O stats of the domain as provided by Libvirt command domstats
     # The metrics are aggregated for all DIKS and NIC
     def io_stats
@@ -411,6 +432,200 @@ class Domain < BaseDomain
         end
     end
 
+    # Detects if VM has GPU by parsing PCI devices from domain metadata
+    # Returns hash with vendor and device_id, or nil if no GPU found
+    def vm_has_gpu?
+        return unless @vm[:pci_devices]
+
+        pci_devices_string = @vm[:pci_devices].strip
+        return if pci_devices_string.empty?
+
+        pci_devices_string.split(',').map(&:strip).each do |pci_device|
+            parts = pci_device.split(':')
+            next if parts.size < 3
+
+            vendor_id = parts[0].downcase
+            device_id = parts[1].downcase
+
+            GPU_VENDORS.each do |vendor_name, config|
+                if vendor_id == config[:vendor_id].downcase
+                    return { :vendor => vendor_name, :device_id => device_id }
+                end
+            end
+        end
+
+        nil
+    end
+
+    # NVIDIA GPU Monitor implementation
+    # --------------------------------------------------------------------------
+    # Collects GPU metrics from VMs using nvidia-smi via QEMU guest agent
+    # Must implement collect_metrics() returning hash with:
+    # :utilization, :memory_utilization, :memory_free, :power_usage, and :count keys
+    class NvidiaGPUMonitor
+
+        # Map nvidia-smi query fields to internal metric names
+        NVIDIA_METRIC_MAP = {
+            'gpu_uuid'            => :gpu_uuid,           # Unique GPU identifier
+            'utilization.gpu'     => :utilization,        # % of time GPU cores busy
+            'utilization.memory'  => :memory_utilization, # % of time memory busy (bandwidth usage)
+            'power.draw'          => :power_usage,        # Power consumption (in Watts)
+            'memory.free'         => :memory_free         # VRAM not allocated (in MiB)
+            # 'memory.used'         => :memory_used,         # VRAM allocated (in MiB)
+            # 'memory.total'        => :memory_total,        # Total installed VRAM (in MiB)
+            # 'temperature.gpu'     => :temperature,         # Core GPU temperature (in Celsius)
+            # 'utilization.encoder' => :encoder_utilization, # % usage of the video encoder engine
+            # 'utilization.decoder' => :decoder_utilization, # % usage of the video decoder engine
+        }.freeze
+
+        NVIDIA_FIELDS = NVIDIA_METRIC_MAP.keys.freeze
+
+        def initialize(domain_name, device_id = nil)
+            @domain_name = domain_name
+            @device_id   = device_id # Store for future model specific logic
+        end
+
+        def collect_metrics
+            2.times do
+                fields  = NVIDIA_FIELDS.join(',')
+                command = "nvidia-smi --query-gpu=#{fields} --format=csv,noheader,nounits"
+                output  = run_guest_command(command)
+
+                if output && !output.empty?
+                    return parse_nvidia_smi_output(output)
+                end
+
+                sleep 1
+            end
+            nil
+        end
+
+        private
+
+        def run_guest_command(command, timeout = 2.0, poll_interval = 0.2)
+            exec_ga = {
+                'execute'   => 'guest-exec',
+                'arguments' => {
+                    'path' => '/bin/sh',
+                    'arg'  => ['-c', command],
+                    'capture-output' => true
+                }
+            }.to_json
+
+            text, _e, s = KVM.virsh(:qemuga, "#{@domain_name} '#{exec_ga}' --timeout 15")
+            return unless s.success?
+
+            response = JSON.parse(text) rescue nil
+            return unless response&.dig('return', 'pid')
+
+            pid     = response['return']['pid']
+            elapsed = 0.0
+
+            while elapsed < timeout
+                sleep poll_interval
+                elapsed += poll_interval
+
+                stat_ga = {
+                    'execute'   => 'guest-exec-status',
+                    'arguments' => { 'pid' => pid }
+                }.to_json
+
+                text, _e, s = KVM.virsh(:qemuga, "#{@domain_name} '#{stat_ga}' --timeout 15")
+                next unless s.success?
+
+                status = JSON.parse(text) rescue nil
+                if status&.dig('return', 'exited')
+                    return Base64.decode64(status['return']['out-data']) rescue nil
+                end
+            end
+            nil
+        end
+
+        def parse_nvidia_smi_output(text)
+            return if !text || text.empty?
+
+            devices = []
+
+            CSV.parse(text, :headers => false) do |row|
+                next if row.size < NVIDIA_FIELDS.size
+
+                device_data = {}
+                row.each_with_index do |value, i|
+                    field_name = NVIDIA_FIELDS[i]
+                    metric_key = NVIDIA_METRIC_MAP[field_name]
+
+                    if metric_key == :gpu_uuid
+                        device_data[metric_key] = value&.strip
+                    else
+                        device_data[metric_key] = parse_numeric(value)
+                    end
+                end
+                devices << device_data
+            end
+
+            return if devices.empty?
+
+            aggregate_gpu_metrics(devices)
+        end
+
+        def parse_numeric(value)
+            return 0.0 if value.nil? || value.strip.empty? || value.strip.downcase == 'n/a'
+
+            cleaned = value.strip.gsub(/[^\d.-]/, '')
+            cleaned.to_f
+        rescue StandardError
+            0.0
+        end
+
+        def aggregate_gpu_metrics(devices)
+            return {} if devices.empty?
+
+            gpu_count = devices.size
+            agg = Hash.new(0.0)
+
+            devices.each do |gpu|
+                gpu.each do |key, value|
+                    next if key == :gpu_uuid
+
+                    agg[key] += value
+                end
+            end
+
+            # Average utilization metrics
+            avg_keys = [:utilization, :memory_utilization]
+            avg_keys.each {|k| agg[k] = (agg[k] / gpu_count).round(2) if agg[k] > 0 }
+
+            agg[:count] = gpu_count
+            agg.transform_values {|v| v.round(2) }
+        end
+
+    end
+
+    # Get the VM GPU stats
+    # The metrics are aggregated for all GPUs
+    # Only sets GPU metrics if VM actually has a GPU
+    def gpu_stats
+        return unless @vm[:state] == 'RUNNING'
+
+        gpu_info = vm_has_gpu?
+        return unless gpu_info
+
+        vendor_config = GPU_VENDORS[gpu_info[:vendor]]
+        monitor_class = Object.const_get("Domain::#{vendor_config[:monitor_class]}")
+        monitor = monitor_class.new(@name, gpu_info[:device_id])
+
+        stats = monitor.collect_metrics
+        if stats
+            @vm[:gpu_utilization] = stats[:utilization] || 0.0
+            @vm[:gpu_memory_utilization] = stats[:memory_utilization] || 0.0
+            @vm[:gpu_memory_free] = stats[:memory_free] || 0.0
+            @vm[:gpu_power_usage] = stats[:power_usage] || 0.0
+            @vm[:gpu_count] = stats[:count] || 0
+        end
+    rescue StandardError => e
+        STDERR.puts "Warning: Failed to get GPU stats for VM #{@name}: #{e.message}"
+    end
+
 end
 
 #-------------------------------------------------------------------------------
